/*****************************************************************************
 *   main.c:  main C entry file for Philips LPC214x Family Microprocessors
 *
 *   Copyright(C) 2006, Philips Semiconductor
 *   All rights reserved.
 *
 *   History
 *   2005.10.01  ver 1.00    Prelimnary version, first Release
 *
******************************************************************************/

#include "irq.h"
#include "lpc214x.h"

#define LED (1 << 30)

static void switchLED()
{
   static char flip;
   if (flip) IOCLR0 = LED; else IOSET0 = LED;
   flip = !flip;
}

void IRQ_Timer0 (void) __irq;
void IRQ_Timer0()
{
    ISR_ENTER();
    switchLED();           // Methode zum toggeln der LED
    T0IR = 0x01;           // Rcksetzen des Timerinterrupts
    VICVectAddr = 0;       // Acknowledge Interrupt
    ISR_EXIT();
}

/*****************************************************************************
**   Main Function  main()
*****************************************************************************/
#include "target_init.inc"
int main (void)
{	 
   target_init();  // PLL und MAM
   
   IODIR0 = LED;
   T0PR = 0x0;
  //Prescale Register (berlaufwert) 0 => pclk = 58.9824MHz = Timer-Clock

  T0MCR = 0x3;
  //TimerCounter = MatchRegister0 => Interrupt 0 + Timer Counter Reset

  T0MR0=58982400;
  //MatchRegister0 entspricht 0.5s

  T0TCR=0x2;
  //Prescale-Counter und Timer-Counter werden resettet

  T0TCR=0x1;
  //Prescale-Counter und Timer-Counter werden gestarte

  irq_init();
  irq_install(TIMER0_INT, IRQ_Timer0);
  irq_enableIRQ();
  
  for (;;);
	
    return 0;
}
 
/*****************************************************************************
**                            End Of File
******************************************************************************/
